#!/bin/sh
# Never ever curl some remote shit straight to shell, like:
# curl --proto '=https' --tlsv1.2 -sSf https://inex.dev/v/dotfiles/raw/branch/main/dot_scripts/executable_install_base.sh | sh
# seriously, don't do this, it's insecure!

## Pacman
# Enable multilib
sudo sed -z -i -e 's/#\[multilib\]\n#Include = \/etc\/pacman.d\/mirrorlist/\[multilib\]\nInclude = \/etc\/pacman.d\/mirrorlist/' /etc/pacman.conf
# Workaround for keyring nonsense, see https://bugs.archlinux.org/task/75574
sudo pacman -Sy --needed --noconfirm archlinux-keyring
sudo pacman -Su --needed --noconfirm
# Install packages
sudo pacman --needed --noconfirm -S base-devel htop ranger git screen ncdu neovim pipewire sway swaybg xorg-server xorg-xwayland chezmoi foot polkit openssh firefox-developer-edition gnome-keyring xdg-utils qpwgraph qt6-wayland man-db udisks2 ttf-cascadia-code ponysay lm_sensors

## Paru (AUR helper)
# Install Paru from AUR if not installed
if pacman -Qs paru > /dev/null ; then
  echo "'Paru' already installed."
else
  git clone https://aur.archlinux.org/paru-bin.git
  cd paru-bin/
  makepkg --needed --noconfirm -si
  cd ..
  rm -rf paru-bin/
fi

## AUR Packages
paru --needed --noconfirm -Syua paru-bin bashmount ulauncher

## Chezmoi
# Get and apply dotfiles
chezmoi init --apply https://inex.dev/v/dotfiles.git
cd ~/.local/share/chezmoi/
git remote set-url origin git@inex.dev:v/dotfiles.git
cd ~

## SSH
# Generate key if not exist
if [ -f "$HOME/.ssh/id_ed25519.pub" ]; then
    echo "id_ed25519.pub exist"
else 
    echo "creating id_ed25519.pub..."
    ssh-keygen -t ed25519 -f "$HOME/.ssh/id_ed25519" -N ""
    eval "$(ssh-agent -s)"
    ssh-add ~/.ssh/id_ed25519
fi

## Neovim
if [ ! -f ~/.local/share/nvim/autoload/plug.vim ]; then
  echo "Installing vim-plug"
  curl -fLo ~/.local/share/nvim/site/autoload/plug.vim --create-dirs https://raw.githubusercontent.com/junegunn/vim-plug/master/plug.vim
else
  echo "vim-plug already installed"
fi


## Add user to useful groups
sudo usermod -aG wheel,input,audio,video,lp v

## Apply Firefox policies, see https://github.com/mozilla/policy-templates/blob/master/README.md
sudo mkdir -p /etc/firefox/policies
sudo cp ~/.scripts/firefox_policies.json /etc/firefox/policies/policies.json

## Fix NTFS Mount, see https://wiki.archlinux.org/title/NTFS#udisks_support
sudo cp ~/.scripts/mount_options.conf /etc/udisks2/mount_options.conf

